
# Type: boolean


A binary (true or false) value

URI: [https://example.com/test65/meta:types/Boolean](https://example.com/test65/meta:types/Boolean)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **Bool** |
